============
Installation
============

Download source then, at the command line::

    $ python setup.py install

{% if 'pypi' is available %}
Alternatively the command line::

    $ easy_install pkglts

Or::

    $ pip install pkglts

Preferred method use virtual environments::

    $ virtualenv 'myenv'
    $ myenv/scripts/activate
    (myenv)$ pip install pkglts

{% endif %}
